import { DataGrid, SelectionModel } from 'tde-datagrid';
import { LabIcon } from '@jupyterlab/ui-components';
export declare class PaintedGrid extends DataGrid {
    constructor(options: PaintedGrid.IOptions);
    /**
     * Get the extra styles of the PaintedGrid.
     */
    get extraStyle(): PaintedGrid.ExtraStyle;
    /**
     * Set the styles of the painted grid.
     */
    set extraStyle(value: PaintedGrid.ExtraStyle);
    /**
     * Get the ghost row height.
     */
    get ghostRowHeight(): number;
    /**
     * Get the ghost column width.
     */
    get ghostColumnWidth(): number;
    /**
     * Selects cells using the selection model
     * @param row The row being selected
     * @param column The column being selected
     */
    selectCells(selection: SelectionModel.Selection): void;
    /**
     * @override paints on the ghost row and column as well after painting the other regions.
     * Paint the grid content for the given dirty rect.
     *
     * The rect should be expressed in valid viewport coordinates.
     *
     * This is the primary paint entry point. The individual `_draw*`
     * methods should not be invoked directly. This method dispatches
     * to the drawing methods in the correct order.
     */
    paintContent(rx: number, ry: number, rw: number, rh: number): void;
    /**
     * Primary entry point for painting additional graphics on top of
     * the base data grid graphics.
     */
    private _paintAddons;
    /**
     * Draw the ghost row.
     * @param rx
     * @param ry
     * @param rw
     * @param rh
     */
    private _drawGhostRow;
    /**
     * Draw the ghost column.
     * @param rx
     * @param ry
     * @param rw
     * @param rh
     */
    private _drawGhostColumn;
    /**
     * Draw the ghost row header
     * @param rx
     * @param ry
     * @param rw
     * @param rh
     */
    private _drawGhostRowHeader;
    /**
     * Draw the ghost column header
     * @param rx
     * @param ry
     * @param rw
     * @param rh
     */
    private _drawGhostColumnHeader;
    /**
     * Paints the ghost row icon
     */
    private _paintGhostRowIcon;
    /**
     * Paints the ghost column icon
     */
    private _paintGhostColumnIcon;
    private _drawOverCorner;
    /**
     * Paints the datatype icons (string, number, boolean, date)
     * @param rx
     * @param ry
     * @param rw
     * @param rh
     */
    private _paintDatatypeIcons;
    /**
     * Utilizes the canvas GC to draw the icon in the correct position with the correct styles
     * @param x The horizontal position of the icon
     * @param y The vertical position of the icon
     * @param size The original size of the icon
     * @param color The fill color for the icon
     * @param svgstr A string containing the raw contents of the svg file
     */
    private _drawIcon;
    private _extraStyle;
}
/**
 * Namespace for class statics.
 */
export declare namespace PaintedGrid {
    /**
     * The options for creating a new PaintedGrid.
     */
    interface IOptions extends DataGrid.IOptions {
        extraStyle?: ExtraStyle;
    }
    /**
     * The extra styling options for a painted grid.
     */
    type ExtraStyle = {
        /**
         * The color of the ghost row.
         *
         * NOTE: This is painted on top of the last row and so
         * in most cases an opaque color is chosen.
         */
        ghostRowColor?: string;
        /**
         * The color of the ghost column.
         *
         * NOTE: This is painted on top of the last column and so
         * in most cases an opaque color is chosen.
         */
        ghostColumnColor?: string;
        /**
         * A object mapping data types to Icons.
         */
        icons?: {
            [key: string]: IIconArgs;
        };
    };
    type IIconArgs = {
        /**
         * The icon to paint on the grid.
         */
        icon: LabIcon;
        /**
         * The fill color for the icon.
         */
        color: string;
        /**
         * Distance right in pixcels from the left cell boundary.
         */
        left?: number;
        /**
         * Distance right in pixcels from the top cell boundary.
         */
        top?: number;
        /**
         * Size of icon in pixcels.
         */
        size?: number;
    };
}
